Package: multiDimBio
Type: Package
Title: Multivariate Analysis and Visualization for Biological Data
Version: 1.2.5
Date: 2025-05-13
Authors@R: person(given = c("Samuel", "V."),
                    family = "Scarpino",
                    role = c("aut", "cre"),
                    email = "scarpino@utexas.edu")
Description: Code to support a systems biology research program from inception through publication.  The methods focus on dimension reduction approaches to detect patterns in complex, multivariate experimental data and places an emphasis on informative visualizations.  The goal for this project is to create a package that will evolve over time, thereby remaining relevant and reflective of current methods and techniques.  As a result, we encourage suggested additions to the package, both methodological and graphical.
License: GPL (>= 3.0)
LazyLoad: yes
Imports: ggplot2 (>= 3.2.0), lme4 (>= 1.1-21), pcaMethods (>= 1.76.0),
        misc3d (>= 0.8-4), MASS (>= 7.3-29), RColorBrewer(>= 1.1-2),
        gridGraphics (>= 0.1-5)
NeedsCompilation: no
Packaged: 2025-05-13 15:36:41 UTC; scarpino
Author: Samuel V. Scarpino [aut, cre]
Maintainer: Samuel V. Scarpino <scarpino@utexas.edu>
Repository: CRAN
Date/Publication: 2025-05-13 15:50:02 UTC
Built: R 4.6.0; ; 2026-04-28 07:20:26 UTC; unix
